@@ -45,15 +45,13 @@ public class Index {
         final Enumeration<URL> res = cl.getResources("META-INF/annotations/"+type.getName());
         while (res.hasMoreElements()) {
             URL url = res.nextElement();
-            InputStream is = url.openStream();
-            try {
-                BufferedReader r = new BufferedReader(new InputStreamReader(is, "UTF-8"));
+
+            try (InputStream is = url.openStream();
+                 BufferedReader r = new BufferedReader(new InputStreamReader(is, "UTF-8"))) {
                 String line;
                 while ((line = r.readLine()) != null) {
                     ids.add(line);
                 }
-            } finally {
-                is.close();
             }
         }
 
@@ -96,6 +94,11 @@ public class Index {
                             String name = iditr.next();
 
                             try {
+                                if (name.endsWith(".*")) {
+                                    final Package p = Package.getPackage(name.substring(0, name.length() - 2));
+                                    lookaheads.add(p);
+                                }
+
                                 Class<?> c = cl.loadClass(name);
 
                                 if (c.isAnnotationPresent(type))
